@@ -7,9 +7,9 @@ the definitions of the colors from the relevant standards documents.
 import re
 import unittest
 
-from bs4 import BeautifulSoup
-import html5lib
+import html5lib  # noqa: F401
 import requests
+from bs4 import BeautifulSoup
 
 import webcolors
 
@@ -34,12 +34,14 @@ class HTML4DefinitionTests(unittest.TestCase):
         for td in color_table.findAll('td'):
             if u'width' not in td.attrs:
                 color_name, color_value = td.text.split(' = ')
-                self.html4_colors[color_name] = color_value.replace('"', '').strip()
+                self.html4_colors[color_name] = (
+                    color_value.replace('"', '').strip()
+                )
 
     def test_color_definitions(self):
         for color_name, color_value in self.html4_colors.items():
-            self.assertEqual(color_value.lower(),
-                             webcolors.HTML4_NAMES_TO_HEX[color_name.lower()])
+            extracted = webcolors.HTML4_NAMES_TO_HEX[color_name.lower()]
+            assert color_value.lower() == extracted
 
 
 class CSS21DefinitionTests(unittest.TestCase):
@@ -68,8 +70,8 @@ class CSS21DefinitionTests(unittest.TestCase):
 
     def test_color_definitions(self):
         for color_name, color_value in self.css21_colors.items():
-            self.assertEqual(color_value.lower(),
-                             webcolors.CSS21_NAMES_TO_HEX[color_name.lower()])
+            extracted = webcolors.CSS21_NAMES_TO_HEX[color_name.lower()]
+            assert color_value.lower() == extracted
 
 
 class CSS3DefinitionTests(unittest.TestCase):
@@ -109,10 +111,10 @@ class CSS3DefinitionTests(unittest.TestCase):
 
     def test_color_definitions(self):
         for color_name, color_values in self.css3_colors.items():
-            self.assertEqual(color_values['hex'].lower(),
-                             webcolors.CSS3_NAMES_TO_HEX[color_name.lower()])
-            self.assertEqual(color_values['rgb'],
-                             webcolors.name_to_rgb(color_name))
+            extracted_hex = webcolors.CSS3_NAMES_TO_HEX[color_name.lower()]
+            extracted_rgb = webcolors.name_to_rgb(color_name)
+            assert color_values['hex'].lower() == extracted_hex
+            assert color_values['rgb'] == extracted_rgb
 
 
 if __name__ == '__main__':
